struct DebugStats {
last_addr: usize,
stats: HashMap<&'static str, ItemStats>,
}Expand description
Internal info used for more detailed analysis of serialized display lists
Fields
last_addr: usizeLast address in the buffer we pointed to, for computing serialized sizes
stats: HashMap<&'static str, ItemStats>Implementations